@@ -38,7 +38,13 @@ data_plot.bayestestR_eti <- data_plot.hdi
     data <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(data, names = FALSE)))
   } else if (inherits(data, c("stanreg", "brmsfit"))) {
     params <- insight::clean_parameters(data)
-    data <- as.data.frame(data)
+    data <- as.data.frame(data, optional = FALSE)
+  } else if (inherits(data, "BFBayesFactor")) {
+    data <- insight::get_parameters(data)
+  } else if (inherits(data, "MCMCglmm")) {
+    params <- insight::clean_parameters(data)
+    nF <- data$Fixed$nfl
+    data <- as.data.frame(data$Sol[, 1:nF, drop = FALSE])
   } else {
     data <- as.data.frame(data)
   }
@@ -161,7 +167,7 @@ data_plot.bayestestR_eti <- data_plot.hdi
 #' @importFrom rlang .data
 #' @rdname data_plot
 #' @export
-plot.see_hdi <- function(x, data = NULL, show_intercept = FALSE, n_columns = 1, ...) {
+plot.see_hdi <- function(x, data = NULL, show_intercept = FALSE, show_zero = TRUE, show_title = TRUE, n_columns = 1, ...) {
   if (!"data_plot" %in% class(x)) {
     x <- data_plot(x, data = data, show_intercept = show_intercept)
   }
@@ -183,9 +189,17 @@ plot.see_hdi <- function(x, data = NULL, show_intercept = FALSE, n_columns = 1,
       fill = .data$fill
     )) +
     ggridges::geom_ridgeline_gradient() +
-    geom_vline(xintercept = 0, linetype = "dotted") +
     add_plot_attributes(x)
 
+  # Show
+  if (show_zero) {
+    p <- p + geom_vline(xintercept = 0, linetype = "dotted")
+  }
+
+  if (show_title == FALSE) {
+    p <- p + ggtitle("")
+  }
+
   if (length(unique(x$y)) == 1  && is.numeric(x$y)) {
     p <- p + scale_y_continuous(breaks = NULL, labels = NULL)
   } else {
@@ -193,6 +207,7 @@ plot.see_hdi <- function(x, data = NULL, show_intercept = FALSE, n_columns = 1,
   }
 
 
+
   if (!is.null(n_columns)) {
     if ("Component" %in% names(x) && "Effects" %in% names(x)) {
       p <- p + facet_wrap(~ Effects + Component, scales = "free", ncol = n_columns)
